@@ -1,5 +1,6 @@
 import json
 import requests
+import re
 
 from urllib.parse import urlencode
 
@@ -19,10 +20,18 @@ class HttpClient:
 
         auth = requests.auth.HTTPBasicAuth(self.api_key, '')
 
-        headers = {'Content-Type': 'application/x-www-form-urlencoded'}
+        headers = {
+            'Content-Type': 'application/x-www-form-urlencoded'
+        }
 
-        if method.lower() in ['post', 'put']:
-            data = self._encode_params(params)
+        if method.lower() in ['post', 'put', 'delete']:
+            data = re.sub(
+                r'%5B[\d+]%5D', 
+                '%5B%5D',
+                urlencode(
+                    self._http_build_query(params)
+                )
+            )
         else:
             data = None
 
@@ -36,6 +45,24 @@ class HttpClient:
 
         return ApiResource(response.json())
 
+    def _http_build_query(self, params, parent_key='', sep='&'):
+        items = []
+
+        for key, value in params.items():
+            new_key = f"{parent_key}[{key}]" if parent_key else key
+            if isinstance(value, dict):
+                items.extend(self._http_build_query(value, new_key, sep=sep).items())
+            elif isinstance(value, list):
+                for i, v in enumerate(value):
+                    if isinstance(v, dict):
+                        items.extend(self._http_build_query(v, f"{new_key}[{i}]", sep=sep).items())
+                    else:
+                        items.append((f"{new_key}[{i}]", v))
+            else:
+                items.append((new_key, value))
+
+        return dict(items)
+
     def _handle_error(self, response):
         try:
             json_response_body = response.json()
@@ -50,21 +77,3 @@ class HttpClient:
             raise ResourceNotFoundException(json_response_body)
         else:
             raise BaseException(json_response_body)
-
-    def _encode_params(self, params):
-        encoded_params = {}
-        for key, value in params.items():
-            if isinstance(value, list):
-                for item in value:
-                    encoded_params.setdefault(f'{key}[]', []).append(item)
-            elif isinstance(value, dict):
-                for k, v in value.items():
-                    if isinstance(v, dict):
-                        for nk, nv in v.items():
-                            encoded_params.setdefault(f'{key}[{k}][{nk}]', []).append(nv)
-                    else:
-                        encoded_params.setdefault(f'{key}[{k}]', []).append(v)
-            else:
-                encoded_params[key] = value
-
-        return urlencode(encoded_params, doseq=True)
